==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>प्लगिन %1 सिस्टम हेतु संगत नहीं है।</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>ब्लूएटूथ सेवाएं</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>ऑफ करें</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>ऑन करें</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>ब्लूएटूथ सेवाएं</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>ब्लूटूथ</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>ब्लूटूथ</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>कुंजीपटल अभिन्यास जोड़ें</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>दिनांक व समय</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 घंटे का समय</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 घंटे का समय</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>समय सेवाएं</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>नेटवर्क सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>नेटवर्क निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>नेटवर्क सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>क्या आप निश्चित ही %1 वस्तुएँ हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>इस कार्रवाई को पुनः स्थापित नहीं किया जा सकता है</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>अज्ञात डिवाइस</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>अज्ञात वॉल्यूम</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>डिस्क</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>सभी को माउंट से हटाएँ</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>लॉन्चर </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>फैशन मोड</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>दक्षता मोड</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ऊपर</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>नीचे</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>बाएँ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>दाएँ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>दृश्यमान रखें</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>छिपाएँ रखें</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>उपयोग अनुरूप छिपाएँ</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>मोड </translation>
    </message>
    <message>
        <source>Location</source>
        <translation>स्थान</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>स्थिति</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>प्लगिन</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>बहु-कार्य दृश्य</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>डॉक से हटाएँ</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>केबल कनेक्शन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>केबल कनेक्शन सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>केबल रहित कनेक्शन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>केबल रहित कनेक्शन सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>नेटवर्क निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>नेटवर्क सक्रिय करें</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>नेटवर्क सेटिंग्स</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>डिवाइस डिसेबल्ड</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>केबल रहित कनेक्शन : %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>तार वाला कनेक्शन : %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>कनेक्ट नहीं है</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>कनेक्टेड लेकिन इंटरनेट आक्सेस नही है</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>नेटवर्क केबल अनप्लग है </translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>बेतार नेटवर्क</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>तार वाला नेटवर्क</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>नेटवर्क </translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>तार वाला नेटवर्क</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>केबल नेटवर्क %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>ऑनबोर्ड</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>पॉवर</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>पॉवर सेटिंग्स</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>क्षमता %1, %2 मिनट शेष</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>क्षमता %1, %2 घंटे %3 मिनट शेष</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 चार्ज हो रहा है, पूर्ण होने में %2 मिनट शेष</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 चार्ज हो रहा है, पूर्ण होने में %2 घंटे %3 मिनट शेष</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>चार्ज हो रहा है %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>डेस्कटॉप दिखाएँ</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>डॉक से हटाएँ</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>पॉवर</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>हाइबरनेट</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>लॉक स्क्रीन</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>लॉग आउट</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>खाता बदलें</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>पॉवर सेटिंग्स</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>डिवाइस</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>ध्वनि चालू करें</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>ध्वनि बंद करें</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ध्वनि सेटिंग्स</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>ध्वनि %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ध्वनि</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>रद्दी</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>कचरा - %1 फ़ाइल</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>कचरा - %1 फ़ाइलें</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>खाली </translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>सिस्टम ट्रे</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>बेतार नेटवर्क</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>बेतार नेटवर्क %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.1.orig.tar.xz: dde-dock-5.5.38.1/translations/dde-dock_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>प्लगिन %1 सिस्टम हेतु संगत नहीं है।</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>ब्लूएटूथ सेवाएं</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>ऑफ करें</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>ऑन करें</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>ब्लूएटूथ सेवाएं</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>ब्लूटूथ</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>ब्लूटूथ</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>कुंजीपटल अभिन्यास जोड़ें</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>दिनांक व समय</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 घंटे का समय</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 घंटे का समय</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>समय सेवाएं</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>क्या आप निश्चित ही %1 वस्तुएँ हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>इस कार्रवाई को पुनः स्थापित नहीं किया जा सकता है</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>अज्ञात डिवाइस</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>अज्ञात वॉल्यूम</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>डिस्क</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>सभी को माउंट से हटाएँ</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>लॉन्चर </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>फैशन मोड</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>दक्षता मोड</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ऊपर</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>नीचे</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>बाएँ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>दाएँ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>दृश्यमान रखें</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>छिपाएँ रखें</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>उपयोग अनुरूप छिपाएँ</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>मोड </translation>
    </message>
    <message>
        <source>Location</source>
        <translation>स्थान</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>स्थिति</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>प्लगिन</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>बहु-कार्य दृश्य</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>डॉक से हटाएँ</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>ऑनबोर्ड</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>पॉवर</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>पॉवर सेटिंग्स</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>क्षमता %1, %2 मिनट शेष</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>क्षमता %1, %2 घंटे %3 मिनट शेष</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 चार्ज हो रहा है, पूर्ण होने में %2 मिनट शेष</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 चार्ज हो रहा है, पूर्ण होने में %2 घंटे %3 मिनट शेष</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>चार्ज हो रहा है %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>डेस्कटॉप दिखाएँ</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>डॉक से हटाएँ</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>पॉवर</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>हाइबरनेट</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>लॉक स्क्रीन</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>लॉग आउट</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>खाता बदलें</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>पॉवर सेटिंग्स</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>डिवाइस</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>ध्वनि चालू करें</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>ध्वनि बंद करें</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ध्वनि सेटिंग्स</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>ध्वनि %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ध्वनि</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>रद्दी</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>कचरा - %1 फ़ाइल</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>कचरा - %1 फ़ाइलें</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>ट्रैश में ले जाएं </translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>खाली </translation>
    </message>
</context>
</TS>
